@@ -65,6 +65,20 @@
 #    endif
 #  endif
 #endif
+
+#ifdef WITH_TLS
+#  ifdef WITH_COA
+#    ifndef WITHOUT_COA_TUNNEL
+//#      define WITH_COA_TUNNEL (1)
+#    endif
+#  endif
+#endif
+
+#ifdef WITH_COA_TUNNEL
+#  ifdef WITHOUT_TLS
+#    error Reverse CoA requests requires TLS
+#  endif
+#endif
 #define WITH_ASCEND_BINARY 1
 #define WITH_DHCP 1
 #define WITH_NDEBUG 1
@@ -72,5 +86,5 @@
 #define WITH_THREADS 1
 #define WITH_UDPFROMTO /**/
 #define WITH_VMPS 1
-#define RADIUSD_VERSION 030022
-#define RADIUSD_VERSION_STRING "3.0.22"
+#define RADIUSD_VERSION 030024
+#define RADIUSD_VERSION_STRING "3.0.24"
